model {
  # Hyperpriors for state process
  pop_r ~ dnorm(0.304,pop_tau_r) # From koons moose paper
  pop_tau_r <- 1/(pop_sigma_r*pop_sigma_r)
  pop_sigma_r <- 0.08
  
  # DD
  pop_mu_b ~ dnorm(0,1)T(-2,2) # Mean intercept on density dependency, koons bison paper
  pop_tau_b ~ dgamma(0.001, 0.001) # Precision
  pop_sig_b <- 1/sqrt(pop_tau_b) # Standard dev

  # Deer
  pop_mu_deer ~ dnorm(0,1)
  pop_tau_deer ~ dgamma(0.001, 0.001) 
  pop_sig_deer <- 1/sqrt(pop_tau_deer)

  # Pop prior for predator interaction with N
  pop_mu_pred_N ~ dnorm(0,1)
  pop_tau_pred_N ~ dgamma(0.001, 0.001) 
  pop_sig_pred_N <- 1/sqrt(pop_tau_pred_N)

  # Wolf bear interaction priors
  wolf_coy ~ dnorm(0,1)
  bear ~ dnorm(0,1)
  tau_pred ~ dgamma(0.001, 0.001)
  
  # Missing bear data
  for(j in Missing_bear){
    bear_density[j] ~ dnorm(0,0.1)
  }
  
  # Hyperpriors for observations
  # Moose Obs
  mu_a.moose ~ dnorm(0,1)
  tau_a.moose ~ dgamma(0.001, 0.001)
  sig_a.moose <- 1/sqrt(tau_a.moose)
  
  mu_days.moose ~ dnorm(0,1)
  tau_days.moose ~ dgamma(0.001, 0.001)
  sig_days.moose <- 1/sqrt(tau_days.moose)
  
  mu_fsnow.moose ~ dnorm(0,1)
  tau_fsnow.moose ~ dgamma(0.001, 0.001)
  sig_fsnow.moose <- 1/sqrt(tau_fsnow.moose) 
  
  # Process model
  for(wmu in 1:nwmu){
    # Site level priors for state process
    pop_b[wmu] ~ dnorm(pop_mu_b, pop_tau_b)  # Site density dependence
    pop_deer[wmu] ~ dnorm(pop_mu_deer, pop_tau_deer)
    pop_pred_N[wmu] ~ dnorm(pop_mu_pred_N, pop_tau_pred_N) # 

    # Wolf and bear submodel
    pop_pred[wmu] ~ dnorm(mu_pred[wmu],tau_pred) 

    # Add bear and canid together
    mu_pred[wmu] <- wolf_coy + bear*bear_density[wmu]

    # Process error sigma
    pop_tauPro[wmu] ~ dgamma(0.001, 0.001)
    pop_sigPro[wmu] <- 1/sqrt(pop_tauPro[wmu])
    
    # Prior for first year FEb numbers
    logN_JAN_FEB.init[wmu] ~ dnorm(mu.mai.init[wmu],tau.mai.init[wmu])
    logN_JAN_FEB[1,wmu] <- logN_JAN_FEB.init[wmu]
    
    # Site level priors for observations
    a.moose[wmu] ~ dnorm(mu_a.moose,tau_a.moose)
    days.moose[wmu] ~ dnorm(mu_days.moose,tau_days.moose)
    fsnow.moose[wmu] ~ dnorm(mu_fsnow.moose, tau_fsnow.moose)
    
    # Count model sigma
    tau_olre.moose[wmu] ~ dgamma(0.001,0.001)
    obs_sig.moose[wmu] <- 1/sqrt(tau_olre.moose[wmu])
    
    # Observation process, you observe the pre harvest population in the fall
    # There is no preharvest pop on year 1, since we have MAI 1999 in January
    for(i in 1:nyears){ # There is no 2020 
      Seen.moose[i,wmu] ~ dpois(lambda.moose[i,wmu])
      OLRE.moose[i,wmu] ~ dnorm(0, tau_olre.moose[wmu])
      log(lambda.moose[i, wmu]) <- a.moose[wmu] + 
        days.moose[wmu]*Ndays.moose_s[i,wmu] + 
        fsnow.moose[wmu]*Snow_hunt_s[i,wmu] + 
        log(exp(logN_JAN_FEB[i+1,wmu]) + E[i,wmu]) + # You observe pre harvest, not MAI
        OLRE.moose[i,wmu]
    }
    
    # State Process: Population model
    for(yr in 1:nyears){ #
      # Spring population
      pre_harv_mu[yr,wmu] <- pop_r + (1 + pop_b[wmu]) * logN_JAN_FEB[yr,wmu] + 
        pop_pred[wmu] *  predators.per.day_s[yr,wmu] + 
        pop_deer[wmu] * deer_per_day_s[yr,wmu] +
        pop_pred_N[wmu] *  predators.per.day_s[yr,wmu] * logN_JAN_FEB[yr,wmu]
      
      # Harvest
      E.bull[yr,wmu] ~ dbinom(success.bull[yr,wmu],miss_tags.bull[yr,wmu])
      E.cow[yr,wmu] ~ dbinom(success.cow[yr,wmu],miss_tags.cow[yr,wmu])
      E.calf[yr,wmu] ~ dbinom(success.calf[yr,wmu],miss_tags.calf[yr,wmu])
      E[yr,wmu] <- sum(E.bull[yr,wmu],E.cow[yr,wmu],E.calf[yr,wmu],
        kill.moose_Bull[yr,wmu],kill.moose_Cow[yr,wmu],kill.moose_Calf[yr,wmu],
        kill.moose_Z[yr,wmu])
      
      # We need post harv, the number of moose harvested at yr-1  cannot be > than N[yr]
      # So use the max function in case
      pre_harv_N[yr,wmu] <- exp(pre_harv_mu[yr,wmu])
      post_harv_N[yr,wmu] <- max(pre_harv_N[yr,wmu] - E[yr,wmu],1)
      #pharv[yr,wmu] <- E[yr,wmu]/pre_harv_N[yr,wmu]
      post_harv_mu[yr,wmu] <- log(post_harv_N[yr,wmu])

      ##### NEW YEAR yr is now yr + 1 To Match to MAI
      
      # For years with no MAI maintain the current value of tau, but
      # for years with MAI replace them with the MAI tau
      tautmp[yr,wmu] <- pop_tauPro[wmu]*indic.mai[yr+1,wmu] + tau.mai[yr+1,wmu]
      
      # For years with no MAI maintain the value from the growth model (pre_harv_mu), but
      # for years with MAI replace them with MAI mu + Harvest, so that its pre havest numbers 
      mutmp[yr,wmu] <- post_harv_mu[yr,wmu]*indic.mai[yr+1,wmu] + mu.mai[yr+1,wmu]

      # Add in some process error or obs error
      logN_JAN_FEB[yr+1,wmu] ~ dnorm(mutmp[yr,wmu], tautmp[yr,wmu])
    }
  }
}

