# Clear workspace
rm(list=ls())

# set seed
set.seed(1)

# Load libraries
library(jagsUI)
library(sf)

# Load data
load("moose_data_dryad.RData")

# Run Gompertz model using settings in the paper
# gomp_moose <- jags(data = jags_data,
#                    parameters.to.save = params,
#                    model.file = "gompertz_jags.R",
#                    n.chains = 3,
#                    n.adapt = 100000,
#                    n.thin = 200,
#                    n.iter = 2100000,
#                    n.burnin = 100000,
#                    parallel = T,
#                    n.cores = 3)

# Run Gompertz model using default setting
gomp_moose <- jags(data = jags_data,
                   parameters.to.save = params,
                   model.file = "gompertz_jags.R",
                   n.chains = 3,
                   n.adapt = 100,
                   n.iter = 1000,
                   n.burnin = 500,
                   n.thin = 2,
                   parallel = T,
                   n.cores = 3)

# All parameters
sum_tab <- data.frame(gomp_moose$summary)

# Population parameters
pop_params <- c("pop_r",
               "pop_mu_b",
               "wolf_coy",
               "bear",
               "pop_mu_deer",
               "pop_mu_pred_N",
               "mu_a.moose",
               "mu_days.moose",
               "mu_fsnow.moose")
pop_tab <- sum_tab[row.names(sum_tab) %in% pop_params,]
print(pop_tab)
